Index: /anuga_core/source/anuga/examples/run_gong.py
===================================================================
--- /anuga_core/source/anuga/examples/run_gong.py	(revision 3534)
+++ /anuga_core/source/anuga/examples/run_gong.py	(revision 3535)
@@ -20,5 +20,5 @@
      Transmissive_boundary, Time_boundary, Add_value_to_region, File_boundary
 from mesh_factory import rectangular
-from pmesh2domain import pmesh_to_domain, pmesh_to_domain_instance
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain, pmesh_to_domain_instance
 
 from Numeric import array
Index: /anuga_core/source/anuga/examples/run_tsh.py
===================================================================
--- /anuga_core/source/anuga/examples/run_tsh.py	(revision 3534)
+++ /anuga_core/source/anuga/examples/run_tsh.py	(revision 3535)
@@ -21,5 +21,5 @@
 from region import Add_value_to_region, Set_region
 from mesh_factory import rectangular
-from pmesh2domain import pmesh_to_domain_instance
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
 
 from Numeric import array
Index: /anuga_core/source/anuga/examples/runup_convergence.py
===================================================================
--- /anuga_core/source/anuga/examples/runup_convergence.py	(revision 3534)
+++ /anuga_core/source/anuga/examples/runup_convergence.py	(revision 3535)
@@ -14,5 +14,5 @@
 import sys
 
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 from pyvolution.mesh_factory import rectangular_cross
 from pyvolution.shallow_water import Domain
Index: /anuga_core/source/anuga/pmesh/timing.py
===================================================================
--- /anuga_core/source/anuga/pmesh/timing.py	(revision 3534)
+++ /anuga_core/source/anuga/pmesh/timing.py	(revision 3535)
@@ -3,5 +3,5 @@
 """
 from mesh import *
-from pmesh import *
+from anuga.pmesh import *
 import time
 
Index: /anuga_core/source/anuga/pyvolution/check_sww_tsh.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/check_sww_tsh.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/check_sww_tsh.py	(revision 3535)
@@ -8,5 +8,5 @@
 from load_mesh.loadASCII import import_mesh_file
 from shallow_water import Domain
-from pmesh2domain import pmesh_to_domain_instance
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
 
 def check_sww_tsh(sww_file, tsh_file, verbose = False):
Index: /anuga_core/source/anuga/pyvolution/data_manager.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/data_manager.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/data_manager.py	(revision 3535)
@@ -31,5 +31,5 @@
 Manually created files:
 ASC, PRJ:     Digital elevation models (gridded)
-TSH:          Triangular meshes (e.g. created from pmesh)
+TSH:          Triangular meshes (e.g. created from anuga.pmesh)
 NC            Model outputs for use as boundary conditions (e.g from MOST)
 
@@ -3545,5 +3545,5 @@
 
     from shallow_water import Domain
-    from pmesh2domain import pmesh_to_domain_instance
+    from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
     import time, os
     from anuga.pyvolution.data_manager import get_dataobject
Index: /anuga_core/source/anuga/pyvolution/run_tsh_weir.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/run_tsh_weir.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/run_tsh_weir.py	(revision 3535)
@@ -16,5 +16,5 @@
 
 from mesh_factory import rectangular
-from pmesh2domain import pmesh_to_domain
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain
 
 from Numeric import array
Index: /anuga_core/source/anuga/pyvolution/test_pmesh2domain.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/test_pmesh2domain.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/test_pmesh2domain.py	(revision 3535)
@@ -8,4 +8,6 @@
 from shallow_water import Domain
 
+#from anuga.pyvolution.pmesh2domain import *
+
 from pmesh2domain import *
 
@@ -14,7 +16,4 @@
 
 from anuga.coordinate_transforms.geo_reference import Geo_reference
-
-#This is making pyvolution dependent on pmesh.
-# not good.  this should be in a seperate package.(directory)
 from anuga.pmesh.mesh import importMeshFromFile
 
Index: /anuga_core/source/anuga/pyvolution/test_shallow_water.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/test_shallow_water.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/test_shallow_water.py	(revision 3535)
@@ -3341,5 +3341,5 @@
          tags["3"] = b3
 
-         #from pmesh2domain import pmesh_to_domain_instance
+         #from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
          #domain = pmesh_to_domain_instance(fileName, Domain)
 
Index: /anuga_core/source/anuga/pyvolution/tsh2sww.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/tsh2sww.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/tsh2sww.py	(revision 3535)
@@ -11,5 +11,5 @@
 
 from shallow_water import Domain
-from pmesh2domain import pmesh_to_domain_instance
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
 import time, os 
 from anuga.pyvolution.data_manager import get_dataobject   
Index: /anuga_core/source/anuga/pyvolution/view_tsh.py
===================================================================
--- /anuga_core/source/anuga/pyvolution/view_tsh.py	(revision 3534)
+++ /anuga_core/source/anuga/pyvolution/view_tsh.py	(revision 3535)
@@ -8,5 +8,5 @@
 
 from shallow_water import Domain
-from pmesh2domain import pmesh_to_domain_instance
+from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance
 from anuga.pyvolution.util import file_function
 from anuga.utilities.polygon import Polygon_function, read_polygon
Index: /development/cairns_2006/create_mesh.py
===================================================================
--- /development/cairns_2006/create_mesh.py	(revision 3534)
+++ /development/cairns_2006/create_mesh.py	(revision 3535)
@@ -6,6 +6,6 @@
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-from pmesh.mesh import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import *
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 from conversion import convert_latlon_to_xycoords
 
Index: /development/dam_2006/create_mesh.py
===================================================================
--- /development/dam_2006/create_mesh.py	(revision 3534)
+++ /development/dam_2006/create_mesh.py	(revision 3535)
@@ -2,10 +2,7 @@
 """
 
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-# Assume that the root AnuGA dir is included in your pythonpath
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-from pmesh.mesh import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import *
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 
Index: /development/dam_2006/run_dam.py
===================================================================
--- /development/dam_2006/run_dam.py	(revision 3534)
+++ /development/dam_2006/run_dam.py	(revision 3535)
@@ -26,4 +26,5 @@
 # Application specific imports
 import project                 # Definition of file names and polygons
+
 
 def main():
@@ -71,4 +72,5 @@
     domain.set_quantities_to_be_stored(['stage', 'xmomentum', 'ymomentum'])
     domain.set_minimum_sww_depth(0.01)
+    domain.set_store_vertices_uniquely(True)  # for writting to sww
 
     #-------------------------------------------------------------------------
@@ -88,10 +90,9 @@
     domain.set_region('dam','stage',0.2,
                                  location = 'unique vertices') 
-    domain.set_region(Set_region('dam','stage',0.2,
-                                 location = 'unique vertices'))
-    domain.set_store_vertices_uniquely(True)  # for writting to sww
+    #domain.set_region(Set_region('dam','stage',0.2,
+    #                             location = 'unique vertices'))
 
     Br = Reflective_boundary(domain)
-    Bd = Dirichlet_boundary([0,0,0])
+    Bd = Dirichlet_boundary([0,0,0])  # to drain the water out.
     domain.set_boundary( {'wall': Br, 'edge': Bd} )
 
@@ -116,5 +117,5 @@
 
     #-------------------------------------------------------------------------
-    # Calc gauge info
+    # Calculate gauge info
     #-------------------------------------------------------------------------
     interpolate_sww2csv(project.outputtimedir + project.basename +".sww",
Index: /development/momentum_sink/scripts/building_generator.py
===================================================================
--- /development/momentum_sink/scripts/building_generator.py	(revision 3534)
+++ /development/momentum_sink/scripts/building_generator.py	(revision 3535)
@@ -3,6 +3,6 @@
 
 # add inundation dir to your pythonpath
-from pmesh.mesh import Mesh
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import Mesh
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 
Index: /development/momentum_sink/scripts/create_buildings.py
===================================================================
--- /development/momentum_sink/scripts/create_buildings.py	(revision 3534)
+++ /development/momentum_sink/scripts/create_buildings.py	(revision 3535)
@@ -6,6 +6,6 @@
 import array
 # add inundation dir to your pythonpath
-from pmesh.mesh import Mesh
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import Mesh
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 WidtH = 200 # width of boudary in metres
Index: /development/momentum_sink/scripts/create_two_buildings.py
===================================================================
--- /development/momentum_sink/scripts/create_two_buildings.py	(revision 3534)
+++ /development/momentum_sink/scripts/create_two_buildings.py	(revision 3535)
@@ -4,6 +4,6 @@
 import random
 # add inundation dir to your pythonpath
-from pmesh.mesh import Mesh
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import Mesh
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 WidtH = 200 # width of boudary in metres
Index: /development/momentum_sink/scripts/friction_block.py
===================================================================
--- /development/momentum_sink/scripts/friction_block.py	(revision 3534)
+++ /development/momentum_sink/scripts/friction_block.py	(revision 3535)
@@ -3,6 +3,6 @@
 
 # add inundation dir to your pythonpath
-from pmesh.mesh import Mesh
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import Mesh
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 
Index: /development/momentum_sink/scripts/loop_buildings.py
===================================================================
--- /development/momentum_sink/scripts/loop_buildings.py	(revision 3534)
+++ /development/momentum_sink/scripts/loop_buildings.py	(revision 3535)
@@ -15,5 +15,5 @@
 import project
 from create_buildings import create_mesh
-from pmesh.mesh import importMeshFromFile
+from anuga.pmesh.mesh import importMeshFromFile
 import Numeric
 
Index: /development/momentum_sink/scripts/loop_friction.py
===================================================================
--- /development/momentum_sink/scripts/loop_friction.py	(revision 3534)
+++ /development/momentum_sink/scripts/loop_friction.py	(revision 3535)
@@ -18,5 +18,5 @@
 from anuga.pyvolution.least_squares import fit_to_mesh_file, DEFAULT_ALPHA 
 from friction_block import create_mesh
-from pmesh.mesh import importMeshFromFile
+from anuga.pmesh.mesh import importMeshFromFile
 
 # generation of friction value list
Index: /development/momentum_sink/scripts/plot_cross_section.py
===================================================================
--- /development/momentum_sink/scripts/plot_cross_section.py	(revision 3534)
+++ /development/momentum_sink/scripts/plot_cross_section.py	(revision 3535)
@@ -7,5 +7,5 @@
 from anuga.pyvolution.util import file_function
 #from anuga.pyvolution.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
-#from coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
+#from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
 from pylab import *
 #from compare_sww import gauge_locations
Index: /development/momentum_sink/scripts/run_buildings.py
===================================================================
--- /development/momentum_sink/scripts/run_buildings.py	(revision 3534)
+++ /development/momentum_sink/scripts/run_buildings.py	(revision 3535)
@@ -18,5 +18,5 @@
 #from building_generator import create_mesh
 
-from pmesh.mesh import importMeshFromFile
+from anuga.pmesh.mesh import importMeshFromFile
 
 depth = 3.5 # depth of building side to oncoming wave
Index: /development/momentum_sink/scripts/run_friction.py
===================================================================
--- /development/momentum_sink/scripts/run_friction.py	(revision 3534)
+++ /development/momentum_sink/scripts/run_friction.py	(revision 3535)
@@ -25,5 +25,5 @@
 #from building_generator import create_mesh
 
-from pmesh.mesh import importMeshFromFile
+from anuga.pmesh.mesh import importMeshFromFile
 
 meshname = project_friction.meshname
Index: /development/momentum_sink/scripts/two_friction_block.py
===================================================================
--- /development/momentum_sink/scripts/two_friction_block.py	(revision 3534)
+++ /development/momentum_sink/scripts/two_friction_block.py	(revision 3535)
@@ -3,6 +3,6 @@
 
 # add inundation dir to your pythonpath
-from pmesh.mesh import Mesh
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import Mesh
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 
Index: /development/okushiri_2005/create_mesh.py
===================================================================
--- /development/okushiri_2005/create_mesh.py	(revision 3534)
+++ /development/okushiri_2005/create_mesh.py	(revision 3535)
@@ -6,6 +6,6 @@
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-from pmesh.mesh import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import *
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 #-------------------------------------------------------------
Index: /development/pyvolution-1d/data_manager.py
===================================================================
--- /development/pyvolution-1d/data_manager.py	(revision 3534)
+++ /development/pyvolution-1d/data_manager.py	(revision 3535)
@@ -54,5 +54,5 @@
 
 
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 def make_filename(s):
@@ -1053,5 +1053,5 @@
 
     #Georeferencing
-    from coordinate_transforms.geo_reference import Geo_reference
+    from anuga.coordinate_transforms.geo_reference import Geo_reference
     if zone is None:
         assert xllcorner is None, 'xllcorner must be None'
@@ -2309,5 +2309,5 @@
 
     #Store
-    from coordinate_transforms.redfearn import redfearn
+    from anuga.coordinate_transforms.redfearn import redfearn
     x = zeros(number_of_points, Float)  #Easting
     y = zeros(number_of_points, Float)  #Northing
@@ -3439,5 +3439,5 @@
     from Scientific.IO.NetCDF import NetCDFFile
 
-    from coordinate_transforms.redfearn import redfearn
+    from anuga.coordinate_transforms.redfearn import redfearn
 
     precision = Float # So if we want to change the precision its done here
@@ -3591,5 +3591,5 @@
 
     #Store
-    from coordinate_transforms.redfearn import redfearn
+    from anuga.coordinate_transforms.redfearn import redfearn
     x = zeros(number_of_points, Float)  #Easting
     y = zeros(number_of_points, Float)  #Northing
Index: /development/pyvolution-1d/domain.py
===================================================================
--- /development/pyvolution-1d/domain.py	(revision 3534)
+++ /development/pyvolution-1d/domain.py	(revision 3535)
@@ -8,5 +8,5 @@
 """
 from generic_boundary_conditions import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 class Domain:
Index: /development/stochastic_study/create_mesh.py
===================================================================
--- /development/stochastic_study/create_mesh.py	(revision 3534)
+++ /development/stochastic_study/create_mesh.py	(revision 3535)
@@ -6,6 +6,6 @@
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-from pmesh.mesh import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import *
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
 #-------------------------------------------------------------
Index: /production/broome_2006/project.py
===================================================================
--- /production/broome_2006/project.py	(revision 3534)
+++ /production/broome_2006/project.py	(revision 3535)
@@ -6,6 +6,6 @@
 #from anuga.utilities.polygon import read_polygon
 import sys
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 from time import localtime, strftime
 from anuga.geospatial_data.geospatial_data import *
@@ -87,5 +87,5 @@
 refzone = 50 
 
-from coordinate_transforms.redfearn import redfearn
+from anuga.coordinate_transforms.redfearn import redfearn
 # boundary up to 50 m contour
 lat1_50 = degminsec2decimal_degrees(-19,20,0)
Index: /production/broome_2006/run_broome.py
===================================================================
--- /production/broome_2006/run_broome.py	(revision 3534)
+++ /production/broome_2006/run_broome.py	(revision 3535)
@@ -97,5 +97,5 @@
 #-------------------------------------------------------------------------------
 
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 region_res = 500000
Index: /production/gippsland_2005/create_mesh2.py
===================================================================
--- /production/gippsland_2005/create_mesh2.py	(revision 3534)
+++ /production/gippsland_2005/create_mesh2.py	(revision 3535)
@@ -4,6 +4,6 @@
 
 # add inundation dir to your pythonpath
-from pmesh.mesh import *
-from coordinate_transforms.geo_reference import Geo_reference
+from anuga.pmesh.mesh import *
+from anuga.coordinate_transforms.geo_reference import Geo_reference
 
     
Index: /production/gippsland_2005/get_timeseries.py
===================================================================
--- /production/gippsland_2005/get_timeseries.py	(revision 3534)
+++ /production/gippsland_2005/get_timeseries.py	(revision 3535)
@@ -6,5 +6,5 @@
 from anuga.pyvolution.util import file_function
 #from anuga.pyvolution.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
-from coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
 from pylab import *
 
Index: /production/karratha_2005/project.py
===================================================================
--- /production/karratha_2005/project.py	(revision 3534)
+++ /production/karratha_2005/project.py	(revision 3535)
@@ -38,5 +38,5 @@
 
 #Georeferencing
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 #Origin of existing dem (FIXME: Temporary measure)
Index: /production/karratha_2005/run_karratha.py
===================================================================
--- /production/karratha_2005/run_karratha.py	(revision 3534)
+++ /production/karratha_2005/run_karratha.py	(revision 3535)
@@ -84,5 +84,5 @@
 
 #Create Triangular Mesh
-from pmesh.create_mesh import create_mesh_from_regions
+from anuga.pmesh.create_mesh import create_mesh_from_regions
 
 resolution = 4000
Index: /production/onslow_2006/get_timeseries.py
===================================================================
--- /production/onslow_2006/get_timeseries.py	(revision 3534)
+++ /production/onslow_2006/get_timeseries.py	(revision 3535)
@@ -5,5 +5,5 @@
 import project
 from anuga.pyvolution.util import file_function
-from coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
 from pylab import *
 from os import sep
Index: /production/onslow_2006/make_gauges.py
===================================================================
--- /production/onslow_2006/make_gauges.py	(revision 3534)
+++ /production/onslow_2006/make_gauges.py	(revision 3535)
@@ -7,5 +7,5 @@
 from anuga.utilities.polygon import poly_xy, is_inside_polygon
 from Numeric import arange
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
 
 x_bound, y_bound = poly_xy(project.polyAll)
Index: /production/onslow_2006/plot_data_extent.py
===================================================================
--- /production/onslow_2006/plot_data_extent.py	(revision 3534)
+++ /production/onslow_2006/plot_data_extent.py	(revision 3535)
@@ -1,6 +1,6 @@
 from pylab import *
 from anuga.geospatial_data.geospatial_data import *
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 from os import sep
 from anuga.utilities.polygon import inside_polygon
@@ -17,5 +17,5 @@
 
 def read_community_file(filename1, filename2, polygon):
-    from coordinate_transforms.redfearn import redfearn
+    from anuga.coordinate_transforms.redfearn import redfearn
     from anuga.utilities.polygon import inside_polygon
     fid1 = open(filename1)
Index: /production/onslow_2006/project.py
===================================================================
--- /production/onslow_2006/project.py	(revision 3534)
+++ /production/onslow_2006/project.py	(revision 3535)
@@ -8,7 +8,7 @@
 import sys
 
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
-
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
+
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 from time import localtime, strftime, gmtime
@@ -135,5 +135,5 @@
 
 #Georeferencing
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 refzone = 50
Index: /production/onslow_2006/project_new.py
===================================================================
--- /production/onslow_2006/project_new.py	(revision 3534)
+++ /production/onslow_2006/project_new.py	(revision 3535)
@@ -8,7 +8,7 @@
 import sys
 
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
 
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 from time import localtime, strftime
@@ -85,5 +85,5 @@
 
 #Georeferencing
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 refzone = 50
Index: /production/onslow_2006/project_old.py
===================================================================
--- /production/onslow_2006/project_old.py	(revision 3534)
+++ /production/onslow_2006/project_old.py	(revision 3535)
@@ -8,7 +8,7 @@
 import sys
 
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
 
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 from time import localtime, strftime
@@ -87,5 +87,5 @@
 
 #Georeferencing
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 refzone = 50
Index: /production/onslow_2006/run_onslow.py
===================================================================
--- /production/onslow_2006/run_onslow.py	(revision 3534)
+++ /production/onslow_2006/run_onslow.py	(revision 3535)
@@ -115,5 +115,5 @@
 #-------------------------------------------------------------------------------
 
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 #new
Index: /production/onslow_2006/run_onslow_new.py
===================================================================
--- /production/onslow_2006/run_onslow_new.py	(revision 3534)
+++ /production/onslow_2006/run_onslow_new.py	(revision 3535)
@@ -103,5 +103,5 @@
 #-------------------------------------------------------------------------------
 
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 # original
Index: /production/onslow_2006/run_onslow_old.py
===================================================================
--- /production/onslow_2006/run_onslow_old.py	(revision 3534)
+++ /production/onslow_2006/run_onslow_old.py	(revision 3535)
@@ -128,5 +128,5 @@
 # resolutions (maximal area of per triangle) for each polygon
 #------------------------------------------------------------------------------
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 # original
Index: /production/pt_hedland_2006/project.py
===================================================================
--- /production/pt_hedland_2006/project.py	(revision 3534)
+++ /production/pt_hedland_2006/project.py	(revision 3535)
@@ -7,6 +7,6 @@
 #from anuga.utilities.polygon import read_polygon
 import sys
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 from time import localtime, strftime
 from anuga.geospatial_data.geospatial_data import *
@@ -111,5 +111,5 @@
 refzone = 50 
 
-from coordinate_transforms.redfearn import redfearn
+from anuga.coordinate_transforms.redfearn import redfearn
 # boundary up to 50 m contour
 lat1_50 = degminsec2decimal_degrees(-19,20,0)
Index: /production/pt_hedland_2006/run_pt_hedland.py
===================================================================
--- /production/pt_hedland_2006/run_pt_hedland.py	(revision 3534)
+++ /production/pt_hedland_2006/run_pt_hedland.py	(revision 3535)
@@ -99,5 +99,5 @@
 #-------------------------------------------------------------------------------
 
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 region_res = 500000
Index: /production/swan_river_tin_2005/thin_generate_alpha.py
===================================================================
--- /production/swan_river_tin_2005/thin_generate_alpha.py	(revision 3534)
+++ /production/swan_river_tin_2005/thin_generate_alpha.py	(revision 3535)
@@ -4,5 +4,5 @@
 
 from anuga.pyvolution.load_mesh.loadASCII import reduce_pts
-from pmesh.mesh import importMeshFromFile
+from anuga.pmesh.mesh import importMeshFromFile
 
 thin_points_file = 'thinned_cross_sections.pts'
Index: /production/sydney_2006/get_timeseries.py
===================================================================
--- /production/sydney_2006/get_timeseries.py	(revision 3534)
+++ /production/sydney_2006/get_timeseries.py	(revision 3535)
@@ -5,5 +5,5 @@
 import project
 from anuga.pyvolution.util import file_function
-#from coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
+#from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, redfearn
 from pylab import *
 from matplotlib.ticker import MultipleLocator, FormatStrFormatter
Index: /production/sydney_2006/project.py
===================================================================
--- /production/sydney_2006/project.py	(revision 3534)
+++ /production/sydney_2006/project.py	(revision 3535)
@@ -8,5 +8,5 @@
 import sys
 
-from pmesh.create_mesh import convert_points_from_latlon_to_utm
+from anuga.pmesh.create_mesh import convert_points_from_latlon_to_utm
                 
 
@@ -77,5 +77,5 @@
 
 #Georeferencing
-from coordinate_transforms.redfearn import degminsec2decimal_degrees
+from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
 
 # define clipping polygon
Index: /production/sydney_2006/run_sydney.py
===================================================================
--- /production/sydney_2006/run_sydney.py	(revision 3534)
+++ /production/sydney_2006/run_sydney.py	(revision 3535)
@@ -45,5 +45,5 @@
 
 #Create Triangular Mesh
-from pmesh.create_mesh import create_mesh_from_regions
+from anuga.pmesh.create_mesh import create_mesh_from_regions
 
 if mytest == 0:
Index: /production/wollongong_2006/run_flagstaff.py
===================================================================
--- /production/wollongong_2006/run_flagstaff.py	(revision 3534)
+++ /production/wollongong_2006/run_flagstaff.py	(revision 3535)
@@ -29,6 +29,6 @@
 from anuga.pyvolution.shallow_water import Reflective_boundary
 from anuga.pyvolution.data_manager import convert_dem_from_ascii2netcdf, dem2pts
-from pmesh.mesh_interface import create_mesh_from_regions
-from pmesh.mesh import importUngenerateFile, Segment
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh import importUngenerateFile, Segment
 
 # Parallelism

Index: /production/sydney_2006/run_sydney_smf.py
===================================================================
--- /production/sydney_2006/run_sydney_smf.py	(revision 3534)
+++ /production/sydney_2006/run_sydney_smf.py	(revision 3535)
@@ -66,7 +66,7 @@
                                  project.combineddemname + '.pts')
 
 #from pmesh.create_mesh import create_mesh_from_regions
 #new interface
-from pmesh.mesh_interface import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 # original issue to Benfield
@@ -66,7 +66,7 @@
                                  project.combineddemname + '.pts')
 
-#from pmesh.create_mesh import create_mesh_from_regions
+#from anuga.pmesh.create_mesh import create_mesh_from_regions
 #new interface
Index: /production/sydney_2006/run_sydney_smf_polyingo.py
===================================================================
--- /production/sydney_2006/run_sydney_smf_polyingo.py	(revision 3534)
+++ /production/sydney_2006/run_sydney_smf_polyingo.py	(revision 3535)
@@ -78,6 +78,6 @@
 # resolutions (maximal area of per triangle) for each polygon
 #-------------------------------------------------------------------------------
-#from pmesh.create_mesh import create_mesh_from_regions
-from pmesh.mesh_interface import create_mesh_from_regions
+#from anuga.pmesh.create_mesh import create_mesh_from_regions
+from anuga.pmesh.mesh_interface import create_mesh_from_regions
 
 meshname = project.meshname4+'.msh'